=============
Device Level
=============

Start by importing analysis submodule for Icarus Pressure Jump for NMR .

.. code-block:: python

  from icarus_nmr import device

TODO: this is not working yet
